import axios from 'axios'
import type { ApiResponse } from '@/types/tools'

// 创建axios实例
const api = axios.create({
  baseURL: '/api',
  timeout: 10000,
  headers: {
    'Content-Type': 'application/json'
  }
})

// 请求拦截器
api.interceptors.request.use(
  (config) => {
    return config
  },
  (error) => {
    return Promise.reject(error)
  }
)

// 响应拦截器
api.interceptors.response.use(
  (response) => {
    return response.data
  },
  (error) => {
    const message = error.response?.data?.message || error.message || '请求失败'
    return Promise.reject(new Error(message))
  }
)

// API方法
export const apiClient = {
  // IP查询
  lookupIp: (ip?: string): Promise<ApiResponse> => {
    const endpoint = ip ? `/ip/${ip}` : '/myip'
    return api.get(endpoint)
  },

  // 获取当前IP
  getMyIp: (): Promise<ApiResponse> => {
    return api.get('/myip')
  },

  // HTTP代理请求
  proxyRequest: (data: {
    url: string
    method?: string
    headers?: Record<string, string>
    body?: string
  }): Promise<ApiResponse> => {
    return api.post('/proxy', data)
  },

  // Markdown转换
  convertMarkdown: (data: {
    content: string
    type: 'html-to-md' | 'md-to-html'
  }): Promise<ApiResponse> => {
    return api.post('/markdown/convert', data)
  },

  // 代码格式化
  formatCode: (data: {
    content: string
    type: string
  }): Promise<ApiResponse> => {
    return api.post('/format/code', data)
  }
}

// 同时提供命名导出和默认导出
export { api }
export default api 